import distribute_compute_config as distribute 

matrix_user = "@matrix_id:matrix.org"
batch_name = "test_batch"
namespace = "test_namespace"
capabilities = ["apptainer"]

meta = distribute.metadata(namespace, batch_name, capabilities, matrix_user)

sif_path = "./path/to/some/container.sif"
# the contents of file.h5 will appear in the /input directory under the name `initial_condition.h5`
initial_condition = distribute.file("./path/to/some/file.h5", relative=True, alias="initial_condition.h5")
# a list of files that will /always/ be present in the /input directory of the container
required_files = [initial_condition]
# a list of paths inside the container that should be mounted to a folder on the host system.
required_mounts = ["/solver/extra_mount"]

initialize = distribute.initialize(sif_path, required_files, required_mounts)

#
# then put together two jobs that will be run using the container 
#

# config files will always appear in `/input` under the name `config.json`.
# we use relative paths since otherwise the file must exist (and this is an example)
job_1_config_file = distribute.file("./path/to/config1.json", alias="config.json", relative=True)
job_2_config_file = distribute.file("./path/to/config2.json", alias="config.json", relative=True)

# all `required files` will appear in the /input directory for their respective job
job_1_required_files = [job_1_config_file]
job_2_required_files = [job_2_config_file]

job_1 = distribute.job("job_1", job_1_required_files)
job_2 = distribute.job("job_2", job_2_required_files)

jobs = [job_1, job_2]

#
# then put together a full description of the jobs that we will run
# and the container we will use to run then
#

description = distribute.description(initialize, jobs)

jobset = distribute.apptainer_config(meta, description)
distribute.write_config_to_file(jobset,"./distribute-jobs.yaml")



from typing import List, Optional

class File(): ...

class Job(): ...

class Initialize(): ...

class Description(): ...

class Meta(): ...

class ApptainerConfig(): ...

def metadata(namespace: str, batch_name: str, capabilities: List[str], matrix_username: Optional[str] = None) -> Meta: ...

def initialize(sif_path: str, requried_files: List[File], required_mounts: List[str]) -> Initialize: ...

def job(name: str, requried_files: List[File]) -> Job: ...

def description(initialize: Initialize, jobs: List[Job]) -> Description: ...

def file(path: str, relative=False, alias=None) -> File: ...

def apptainer_config(meta: Meta, description: Description) -> ApptainerConfig: ...

def write_config_to_file(config: ApptainerConfig, path: str): ...



import os
import random
import pandas
import matplotlib.pyplot as plt

# helper function to debug files
def print_files():
    input_files = list(os.listdir("input/"))
    initial_files = list(os.listdir("initial_files/"))

    print("input files:")
    print(input_files)
    print("initial files:")
    print(initial_files)

def plot_csv(csv_name):
    if os.path.exists(csv_name):
        df = pandas.read_csv(csv_name)
        x = list(df["x"])
        y = list(df["y"])
        title = "perscribed_results"
    else:
        x = list(range(0,11))
        y = list(range(0,11))
        random.shuffle(y)
        title = "random_results"

    plt.plot(x,y)
    plt.title(title)

    return title

def main():
    _ = plot_csv("input/dataset_always.csv")
    save_name = plot_csv("input/dataset.csv")


    plt.savefig("distribute_save/" + save_name + ".png", bbox_inches="tight")
if __name__ == "__main__":
    main()
